@@ -46,12 +46,24 @@ class Projects(Controller):
                 'help': 'Project slug',
                 'action': 'store',
             }),
+            (['--mainapp-required'], {
+                'help': 'if main app is required. Choose main app required as true.',
+                'action': 'store_true',
+                'dest': 'is_main_app_required'
+            }),
+            (['--mainapp-initialize'], {
+                'help': 'Allow you to initialize main app automatically.',
+                'action': 'store_true',
+                'dest': 'initialize_main_app'
+            }),
         ]
     )
     def create(self):
         data = {
             'name': self.app.pargs.name,
             'slug': self.app.pargs.slug,
+            'is_main_app_required': self.app.pargs.is_main_app_required,
+            'initialize_default_app_on_creation': self.app.pargs.initialize_main_app,
         }
         response = self.app.client.create_project(data)
         if response.is_succeed:
@@ -383,12 +395,12 @@ class ProjectApps(Controller):
         for row in rows:
             if 'message' not in row:
                 row['message'] = ""
-        self.app.render(data=response.data,
-                        rows=rows,
-                        headers={'application_type': 'Process Type',
-                                 'message': 'Log',
-                                 'log_timestamp': 'Timestamp'},
-                        is_succeed=response.is_succeed)
+        self.app.render(
+            data=response.data,
+            rows=rows,
+            is_succeed=response.is_succeed,
+            is_log=True,
+        )
 
     @ex(
         help='Export Project App Logs',
